photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h
changeset 1 9ba538e329bd
parent 0 4e91876724a2
child 2 7d9067c6fcb1
--- a/photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h	Thu Dec 17 08:45:44 2009 +0200
+++ b/photosgallery/viewframework/views/fullscreenview/inc/glxfullscreenviewimp.h	Thu Jan 07 12:46:23 2010 +0200
@@ -227,10 +227,10 @@
     /*
     * Calculates and returns the Initial Zoom factor
     */		
-    TInt GetIntialZoomLevel();
+    TInt GetInitialZoomLevel();
     
     /*
     * Calls GetIntialZoomLevel() to get the Zoom Level and Sets the Value to the
     * Slider Level
     */
     void SetSliderLevel();
@@ -227,10 +227,10 @@
     
     /*
-    * Calls GetIntialZoomLevel() to get the Zoom Level and Sets the Value to the
+    * Calls GetInitialZoomLevel() to get the Zoom Level and Sets the Value to the
     * Slider Level
     */